Enum KeyboardInteractivity

#[non_exhaustive]
pub enum KeyboardInteractivity { None, Exclusive, OnDemand, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

No keyboard focus is possible.

This is the default value for all newly created layer shells.



Exclusive

Request exclusive keyboard focus if the layer is above shell surfaces.

For Layer::Top and Layer::Overlay, the seat will always give exclusive access to the layer which has this interactivity mode set.

This setting is intended for applications that need to ensure they receive all keyboard events, such as a lock screen or a password prompt.



OnDemand

The compositor should focus and unfocus this surface by the user in an implementation specific manner.

Compositors may use their normal mechanisms to manage keyboard focus between layers and regular desktop surfaces.

This setting is intended for applications which allow keyboard interaction.