Struct Anchor
pub struct Anchor(/* private fields */);Expand description
Specifies which edges and corners a layer should be placed at in the anchor rectangle.
A combination of two orthogonal edges will cause the layer’s anchor point to be the intersection of
the edges. For example Anchor::TOP and Anchor::LEFT will result in an anchor point in the top
left of the anchor rectangle.
Implementations
impl Anchor
impl Anchor
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<Anchor>
pub const fn from_bits(bits: u32) -> Option<Anchor>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> Anchor
pub const fn from_bits_truncate(bits: u32) -> Anchor
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> Anchor
pub const fn from_bits_retain(bits: u32) -> Anchor
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Anchor>
pub fn from_name(name: &str) -> Option<Anchor>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Anchor) -> bool
pub const fn intersects(&self, other: Anchor) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Anchor) -> bool
pub const fn contains(&self, other: Anchor) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: Anchor)
pub fn remove(&mut self, other: Anchor)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: Anchor, value: bool)
pub fn set(&mut self, other: Anchor, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Anchor) -> Anchor
pub const fn intersection(self, other: Anchor) -> Anchor
The bitwise and (&) of the bits in self and other.
pub const fn difference(self, other: Anchor) -> Anchor
pub const fn difference(self, other: Anchor) -> Anchor
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Anchor) -> Anchor
pub const fn symmetric_difference(self, other: Anchor) -> Anchor
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Anchor
pub const fn complement(self) -> Anchor
The bitwise negation (!) of the bits in self, truncating the result.
impl Anchor
impl Anchor
pub const fn iter(&self) -> Iter<Anchor>
pub const fn iter(&self) -> Iter<Anchor>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Anchor>
pub const fn iter_names(&self) -> IterNames<Anchor>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.